==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/src/app/app-routing.module.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';

import {
  PrinterListComponent, DashboardComponent, PrintStatusComponent,
  MoveComponent, MoveZComponent, MoveEComponent, MoveZBabystepComponent, NetworksComponent,
  GCodesComponent, PrintQueueComponent, ServerCommandsComponent, PrinterCommandsComponent,
  WebcamComponent, ParamsComponent, ImportComponent, WLANComponent, LanguagesComponent, TemperaturesComponent,
  MessagesComponent, ChangeFilamentComponent, ConsoleComponent, ScreensaverComponent, UnlockScreenComponent,
  SettingsComponent, InfoComponent, EepromComponent, TimesettingsComponent, RecoverComponent, WebActionsComponent,
  HardwareInfoComponent, TimelapseComponent
} from "pages";

const routes: Routes = [
  {
    path: 'printer-list',
    component: PrinterListComponent,
    data: {animation: 'p1'}
  },
  {
    path: 'print-status',
    component: PrintStatusComponent,
    data: {animation: 'p2'}
  },
  {
    path: 'move-tool',
    component: MoveComponent,
    data: {animation: 'p3'}
  },
  {
    path: 'move-z-tool',
    component: MoveZComponent,
    data: {animation: 'p4'}
  },
  {
    path: 'move-e-tool',
    component: MoveEComponent,
    data: {animation: 'p5'}
  },
  {   path: 'babystep',
    component: MoveZBabystepComponent,
    data: {animation: 'p6'}
  },
  {
    path: 'network',
    component: NetworksComponent,
    data: {animation: 'p7'}
  },
  {
    path: 'info',
    component: InfoComponent,
    data: {animation: 'p8'}
  },
  {
    path: 'gcodes',
    component: GCodesComponent,
    data: {animation: 'p9'}
  },
  {
    path: 'print-queue',
    component: PrintQueueComponent,
    data: {animation: 'p10'}
  },
  {
    path: 'printer-commands',
    component: PrinterCommandsComponent,
    data: {animation: 'p11'}
  },
  {
    path: 'server-commands',
    component: ServerCommandsComponent,
    data: {animation: 'p12'}
  },
  {
    path: 'webcam',
    component: WebcamComponent,
    data: {animation: 'p13'}
  },
  {
    path: 'params',
    component: ParamsComponent,
    data: {animation: 'p14'}
  },
  {
    path: 'import',
    component: ImportComponent,
    data: {animation: 'p15'}
  },
  {
    path: 'wlan',
    component: WLANComponent,
    data: {animation: 'p16'}
  },
  {
    path: 'temperatures',
    component: TemperaturesComponent,
    data: {animation: 'p17'}
  },
  {
    path: 'languages',
    component: LanguagesComponent,
    data: {animation: 'p18'}
  },
  {
    path: 'messages',
    component: MessagesComponent,
    data: {animation: 'p19'}
  },
  {
    path: 'changefilament',
    component: ChangeFilamentComponent,
    data: {animation: 'p20'}
  },
  {
    path: 'console',
    component: ConsoleComponent,
    data: {animation: 'p21'}
  },
  {
    path: 'screensaver',
    component: ScreensaverComponent,
    data: {animation: 'p22'}
  },
  {
    path: 'eeprom',
    component: EepromComponent,
    data: {animation: 'p23'}
  },
  {
    path: 'unlock',
    component: UnlockScreenComponent,
    data: {animation: 'p24'}
  },
  {
    path: 'settings',
    component: SettingsComponent,
    data: {animation: 'p25'}
  },
  {
    path: 'timesettings',
    component: TimesettingsComponent,
    data: {animation: 'p26'}
  },
  {
    path: 'rescue',
    component: RecoverComponent,
    data: {animation: 'p27'}
  },
  {
    path: 'web-actions',
    component: WebActionsComponent,
    data: {animation: 'p28'}
  },
  {
    path: 'hardware-info',
    component: HardwareInfoComponent,
    data: {animation: 'p29'}
  },
  {
    path: 'timelapse',
    component: TimelapseComponent,
    data: {animation: 'p30'}
  },
  {
    path: '**',
    component: DashboardComponent,
    data: {animation: 'dash'}
  }
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class AppRoutingModule { }

==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/src/app/app-routing.module.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';

import {
  PrinterListComponent, DashboardComponent, PrintStatusComponent,
  MoveComponent, MoveZComponent, MoveEComponent, MoveZBabystepComponent, NetworksComponent,
  GCodesComponent, PrintQueueComponent, ServerCommandsComponent, PrinterCommandsComponent,
  WebcamComponent, ParamsComponent, ImportComponent, WLANComponent, LanguagesComponent, TemperaturesComponent,
  MessagesComponent, ChangeFilamentComponent, ConsoleComponent, ScreensaverComponent, UnlockScreenComponent,
  SettingsComponent, InfoComponent, EepromComponent, TimesettingsComponent, RecoverComponent, WebActionsComponent,
  HardwareInfoComponent, TimelapseComponent, GPIOActionsComponent, ExternalLinkComponent, WizardsComponent
} from "pages";

const routes: Routes = [
  {
    path: 'printer-list',
    component: PrinterListComponent,
    data: {animation: 'p1'}
  },
  {
    path: 'print-status',
    component: PrintStatusComponent,
    data: {animation: 'p2'}
  },
  {
    path: 'move-tool',
    component: MoveComponent,
    data: {animation: 'p3'}
  },
  {
    path: 'move-z-tool',
    component: MoveZComponent,
    data: {animation: 'p4'}
  },
  {
    path: 'move-e-tool',
    component: MoveEComponent,
    data: {animation: 'p5'}
  },
  {   path: 'babystep',
    component: MoveZBabystepComponent,
    data: {animation: 'p6'}
  },
  {
    path: 'network',
    component: NetworksComponent,
    data: {animation: 'p7'}
  },
  {
    path: 'info',
    component: InfoComponent,
    data: {animation: 'p8'}
  },
  {
    path: 'gcodes',
    component: GCodesComponent,
    data: {animation: 'p9'}
  },
  {
    path: 'print-queue',
    component: PrintQueueComponent,
    data: {animation: 'p10'}
  },
  {
    path: 'printer-commands',
    component: PrinterCommandsComponent,
    data: {animation: 'p11'}
  },
  {
    path: 'wizards',
    component: WizardsComponent,
    data: {animation: 'p11'}
  },
  {
    path: 'server-commands',
    component: ServerCommandsComponent,
    data: {animation: 'p12'}
  },
  {
    path: 'webcam',
    component: WebcamComponent,
    data: {animation: 'p13'}
  },
  {
    path: 'params',
    component: ParamsComponent,
    data: {animation: 'p14'}
  },
  {
    path: 'import',
    component: ImportComponent,
    data: {animation: 'p15'}
  },
  {
    path: 'wlan',
    component: WLANComponent,
    data: {animation: 'p16'}
  },
  {
    path: 'temperatures',
    component: TemperaturesComponent,
    data: {animation: 'p17'}
  },
  {
    path: 'languages',
    component: LanguagesComponent,
    data: {animation: 'p18'}
  },
  {
    path: 'messages',
    component: MessagesComponent,
    data: {animation: 'p19'}
  },
  {
    path: 'changefilament',
    component: ChangeFilamentComponent,
    data: {animation: 'p20'}
  },
  {
    path: 'console',
    component: ConsoleComponent,
    data: {animation: 'p21'}
  },
  {
    path: 'screensaver',
    component: ScreensaverComponent,
    data: {animation: 'p22'}
  },
  {
    path: 'eeprom',
    component: EepromComponent,
    data: {animation: 'p23'}
  },
  {
    path: 'unlock',
    component: UnlockScreenComponent,
    data: {animation: 'p24'}
  },
  {
    path: 'settings',
    component: SettingsComponent,
    data: {animation: 'p25'}
  },
  {
    path: 'timesettings',
    component: TimesettingsComponent,
    data: {animation: 'p26'}
  },
  {
    path: 'rescue',
    component: RecoverComponent,
    data: {animation: 'p27'}
  },
  {
    path: 'web-actions',
    component: WebActionsComponent,
    data: {animation: 'p28'}
  },
  {
    path: 'hardware-info',
    component: HardwareInfoComponent,
    data: {animation: 'p29'}
  },
  {
    path: 'timelapse',
    component: TimelapseComponent,
    data: {animation: 'p30'}
  },
  {
    path: 'gpio-actions',
    component: GPIOActionsComponent,
    data: {animation: 'p31'}
  },
  {
    path: 'external-link/:id',
    component: ExternalLinkComponent,
    data: {animation: 'p32'}
  },
  {
    path: '**',
    component: DashboardComponent,
    data: {animation: 'dash'}
  }
];

@NgModule({
  imports: [RouterModule.forRoot(routes, { relativeLinkResolution: 'legacy' })],
  exports: [RouterModule]
})
export class AppRoutingModule { }
